@@ -12,13 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-from oslo_middleware import request_id as oslo_request_id
-from oslo_serialization import jsonutils
+from oslo.config import cfg
 
-from murano.common.i18n import _
 from murano.common import wsgi
 import murano.context
+from murano.openstack.common.gettextutils import _  # noqa
+import murano.openstack.common.log as logging
 
 context_opts = [
     cfg.StrOpt('admin_role', default='admin',
@@ -27,12 +26,12 @@ context_opts = [
 
 CONF = cfg.CONF
 CONF.register_opts(context_opts)
+LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
 class ContextMiddleware(wsgi.Middleware):
     def process_request(self, req):
-
         """Convert authentication information into a request context
 
         Generate a murano.context.RequestContext object from the available
@@ -41,6 +40,7 @@ class ContextMiddleware(wsgi.Middleware):
 
         :param req: wsgi request object that will be given the context object
         """
+
         roles = [r.strip() for r in req.headers.get('X-Roles').split(',')]
         kwargs = {
             'user': req.headers.get('X-User-Id'),
@@ -48,12 +48,8 @@ class ContextMiddleware(wsgi.Middleware):
             'auth_token': req.headers.get('X-Auth-Token'),
             'session': req.headers.get('X-Configuration-Session'),
             'is_admin': CONF.admin_role in roles,
-            'request_id': req.environ.get(oslo_request_id.ENV_REQUEST_ID),
             'roles': roles
         }
-        sc_header = req.headers.get('X-Service-Catalog')
-        if sc_header:
-            kwargs['service_catalog'] = jsonutils.loads(sc_header)
         req.context = murano.context.RequestContext(**kwargs)
 
     @classmethod
