@@ -11,10 +11,7 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-from oslo_log import log as logging
 from sqlalchemy import desc
-from sqlalchemy.orm import load_only
 from webob import exc
 
 from murano.api.v1 import request_statistics
@@ -24,7 +21,9 @@ from murano.common import utils
 from murano.common import wsgi
 from murano.db import models
 from murano.db import session as db_session
-from murano.utils import check_env
+
+from murano.openstack.common.gettextutils import _  # noqa
+from murano.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
@@ -33,41 +32,21 @@ API_NAME = 'Deployments'
 
 class Controller(object):
     @request_statistics.stats_count(API_NAME, 'Index')
-    def index(self, request, environment_id=None):
-        all_environments = environment_id is None
-        LOG.debug('Deployments:List <all_environments: {0}>'
-                  .format(all_environments))
-
-        if all_environments:
-            policy.check("list_deployments_all_environments", request.context)
-        else:
-            check_env(request, environment_id)
-            target = {"environment_id": environment_id}
-            policy.check("list_deployments", request.context, target)
+    def index(self, request, environment_id):
+        target = {"environment_id": environment_id}
+        policy.check("list_deployments", request.context, target)
 
         unit = db_session.get_session()
-
-        if all_environments:
-            query = unit.query(models.Environment) \
-                .options(load_only('tenant_id')) \
-                .filter_by(tenant_id=request.context.project_id) \
-                .join(models.Task) \
-                .order_by(desc(models.Task.created))
-            result = query.all()
-            # The join statement above fetches the deployments into
-            # Environment.tasks. Iterate over that to get the deployments.
-            deployments = []
-            for row in result:
-                for deployment in row.tasks:
-                    deployment = set_dep_state(deployment, unit).to_dict()
-                    deployments.append(deployment)
-        else:
-            query = unit.query(models.Task) \
-                .filter_by(environment_id=environment_id) \
-                .order_by(desc(models.Task.created))
-            result = query.all()
-            deployments = [set_dep_state(deployment, unit).to_dict()
-                           for deployment in result]
+        verify_and_get_env(unit, environment_id, request)
+        query = unit.query(models.Task) \
+            .filter_by(environment_id=environment_id) \
+            .order_by(desc(models.Task.created))
+        result = query.all()
+        # show only tasks with 'deploy' action
+        result = [task for task in result
+                  if (task.action or {}).get('method', 'deploy') == 'deploy']
+        deployments = [set_dep_state(deployment, unit).to_dict() for deployment
+                       in result]
         return {'deployments': deployments}
 
     @request_statistics.stats_count(API_NAME, 'Statuses')
@@ -100,9 +79,19 @@ class Controller(object):
         return {'reports': [status.to_dict() for status in result]}
 
 
+def verify_and_get_env(db_session, environment_id, request):
+    environment = db_session.query(models.Environment).get(environment_id)
+    if not environment:
+        LOG.info(_('Environment with id {0} not found').format(environment_id))
+        raise exc.HTTPNotFound
+
+    if environment.tenant_id != request.context.tenant:
+        LOG.info(_('User is not authorized to access this tenant resources.'))
+        raise exc.HTTPUnauthorized
+    return environment
+
+
 def _patch_description(description):
-    if not description:
-        description = {}
     description['services'] = description.pop('applications', [])
     return token_sanitizer.TokenSanitizer().sanitize(description)
 
@@ -110,13 +99,12 @@ def _patch_description(description):
 def verify_and_get_deployment(db_session, environment_id, deployment_id):
     deployment = db_session.query(models.Task).get(deployment_id)
     if not deployment:
-        LOG.error('Deployment with id {id} not found'
-                  .format(id=deployment_id))
+        LOG.info(_('Deployment with id {0} not found').format(deployment_id))
         raise exc.HTTPNotFound
     if deployment.environment_id != environment_id:
-        LOG.error('Deployment with id {d_id} not found in environment '
-                  '{env_id}'.format(d_id=deployment_id,
-                                    env_id=environment_id))
+        LOG.info(_('Deployment with id {0} not found'
+                   ' in environment {1}').format(deployment_id,
+                                                 environment_id))
         raise exc.HTTPBadRequest
 
     deployment.description = _patch_description(deployment.description)
