@@ -14,25 +14,26 @@
 
 import uuid
 
-from oslo_config import cfg
-from oslo_log import log as logging
-import oslo_messaging as messaging
-from oslo_messaging.rpc import dispatcher
-from oslo_messaging import target
-from oslo_service import service
-from oslo_utils import timeutils
-import pytz
+from oslo import messaging
+from oslo.messaging.notify import dispatcher as oslo_dispatcher
+from oslo.messaging import target
+
 from sqlalchemy import desc
 
+from murano.common import config
 from murano.common.helpers import token_sanitizer
 from murano.db import models
 from murano.db.services import environments
 from murano.db.services import instances
 from murano.db import session
-from murano.engine.system import status_reporter
+from murano.openstack.common.gettextutils import _  # noqa
+from murano.openstack.common import log as logging
+from murano.openstack.common import timeutils
 from murano.services import states
 
-CONF = cfg.CONF
+
+RPC_SERVICE = None
+NOTIFICATION_SERVICE = None
 
 LOG = logging.getLogger(__name__)
 
@@ -42,27 +43,25 @@ class ResultEndpoint(object):
     def process_result(context, result, environment_id):
         secure_result = token_sanitizer.TokenSanitizer().sanitize(result)
         LOG.debug('Got result from orchestration '
-                  'engine:\n{result}'.format(result=secure_result))
-
-        model = result['model']
-        action_result = result.get('action', {})
+                  'engine:\n{0}'.format(secure_result))
 
         unit = session.get_session()
         environment = unit.query(models.Environment).get(environment_id)
 
         if not environment:
-            LOG.warning('Environment result could not be handled, '
-                        'specified environment not found in database')
+            LOG.warning(_('Environment result could not be handled, specified '
+                          'environment was not found in database'))
             return
 
-        if model['Objects'] is None and model.get('ObjectsCopy', {}) is None:
+        if result['Objects'] is None and result.get('ObjectsCopy', {}) is None:
             environments.EnvironmentServices.remove(environment_id)
             return
 
-        environment.description = model
+        environment.description = result
         if environment.description['Objects'] is not None:
             environment.description['Objects']['services'] = \
                 environment.description['Objects'].pop('applications', [])
+            # environment.networking = result.get('networking', {})
             action_name = 'Deployment'
             deleted = False
         else:
@@ -71,10 +70,9 @@ class ResultEndpoint(object):
         environment.version += 1
         environment.save(unit)
 
-        # close deployment
+        #close deployment
         deployment = get_last_deployment(unit, environment.id)
         deployment.finished = timeutils.utcnow()
-        deployment.result = action_result
 
         num_errors = unit.query(models.Status)\
             .filter_by(level='error', task_id=deployment.id).count()
@@ -95,12 +93,12 @@ class ResultEndpoint(object):
         deployment.statuses.append(status)
         deployment.save(unit)
 
-        # close session
+        #close session
         conf_session = unit.query(models.Session).filter_by(
             **{'environment_id': environment.id,
                'state': states.SessionState.DEPLOYING if not deleted
                else states.SessionState.DELETING}).first()
-        if num_errors > 0 or result['action'].get('isException'):
+        if num_errors > 0:
             conf_session.state = \
                 states.SessionState.DELETE_FAILURE if deleted else \
                 states.SessionState.DEPLOY_FAILURE
@@ -108,29 +106,17 @@ class ResultEndpoint(object):
             conf_session.state = states.SessionState.DEPLOYED
         conf_session.save(unit)
 
-        # output application tracking information
-        services = []
-        objects = model['Objects']
-        if objects:
-            services = objects.get('services')
-        if num_errors + num_warnings > 0:
-            LOG.warning('EnvId: {env_id} TenantId: {tenant_id} Status: '
-                        'Failed Apps: {services}'
-                        .format(env_id=environment.id,
-                                tenant_id=environment.tenant_id,
-                                services=services))
-        else:
-            LOG.info('EnvId: {env_id} TenantId: {tenant_id} Status: '
-                     'Successful Apps: {services}'
-                     .format(env_id=environment.id,
-                             tenant_id=environment.tenant_id,
-                             services=services))
-            if action_name == 'Deployment':
-                env = environment.to_dict()
-                env["deployment_started"] = deployment.started
-                env["deployment_finished"] = deployment.finished
-                status_reporter.get_notifier().report(
-                    'environment.deploy.end', env)
+        #output application tracking information
+        message = '<EnvId: {0} TenantId: {1} Status: {2} Apps: {3}>'.format(
+            environment.id,
+            environment.tenant_id,
+            'Failed' if num_errors + num_warnings > 0 else 'Successful',
+            ', '.join(map(
+                lambda a: a['?']['type'],
+                result['Objects']['services']
+            ))
+        )
+        LOG.info(message)
 
 
 def notification_endpoint_wrapper(priority='info'):
@@ -153,7 +139,7 @@ def notification_endpoint_wrapper(priority='info'):
 @notification_endpoint_wrapper()
 def track_instance(payload):
     LOG.debug('Got track instance request from orchestration '
-              'engine:\n{payload}'.format(payload=payload))
+              'engine:\n{0}'.format(payload))
     instance_id = payload['instance']
     instance_type = payload.get('instance_type', 0)
     environment_id = payload['environment']
@@ -169,7 +155,7 @@ def track_instance(payload):
 @notification_endpoint_wrapper()
 def untrack_instance(payload):
     LOG.debug('Got untrack instance request from orchestration '
-              'engine:\n{payload}'.format(payload=payload))
+              'engine:\n{0}'.format(payload))
     instance_id = payload['instance']
     environment_id = payload['environment']
     instances.InstanceStatsServices.destroy_instance(
@@ -179,18 +165,16 @@ def untrack_instance(payload):
 @notification_endpoint_wrapper()
 def report_notification(report):
     LOG.debug('Got report from orchestration '
-              'engine:\n{report}'.format(report=report))
+              'engine:\n{0}'.format(report))
 
-    report['entity_id'] = report.pop('id')
+    report['entity_id'] = report['id']
+    del report['id']
 
     status = models.Status()
-    if 'timestamp' in report:
-        dt = timeutils.parse_isotime(report.pop('timestamp'))
-        report['created'] = dt.astimezone(pytz.utc).replace(tzinfo=None)
     status.update(report)
 
     unit = session.get_session()
-    # connect with deployment
+    #connect with deployment
     with unit.begin():
         running_deployment = get_last_deployment(unit,
                                                  status.environment_id)
@@ -205,78 +189,35 @@ def get_last_deployment(unit, env_id):
     return query.first()
 
 
-class Service(service.Service):
-    """Service class, that contains common methods for custom services"""
-
-    def __init__(self):
-        super(Service, self).__init__()
-        self.server = None
-
-    def stop(self, graceful=False):
-        if self.server:
-            self.server.stop()
-            if graceful:
-                self.server.wait()
-        super(Service, self).stop()
-
-    def reset(self):
-        if self.server:
-            self.server.reset()
-        super(Service, self).reset()
-
-
-def get_notification_listener():
-
-    endpoints = [report_notification, track_instance, untrack_instance]
-    transport = messaging.get_notification_transport(CONF)
-    s_target = target.Target(topic='murano', server=str(uuid.uuid4()))
-    listener = messaging.get_notification_listener(
-        transport, [s_target], endpoints, executor='threading')
-
-    return listener
-
-
-def get_rpc_server():
-
+def _prepare_rpc_service(server_id):
     endpoints = [ResultEndpoint()]
-    transport = messaging.get_rpc_transport(CONF)
-    s_target = target.Target('murano', 'results', server=str(uuid.uuid4()))
-    access_policy = dispatcher.DefaultRPCAccessPolicy
-    server = messaging.get_rpc_server(
-        transport, s_target, endpoints, 'threading',
-        access_policy=access_policy)
 
-    return server
+    transport = messaging.get_transport(config.CONF)
+    s_target = target.Target('murano', 'results', server=server_id)
+    return messaging.get_rpc_server(transport, s_target, endpoints, 'eventlet')
 
 
-class NotificationService(Service):
-    def __init__(self):
-        super(NotificationService, self).__init__()
-        self.server = None
+def _prepare_notification_service(server_id):
+    endpoints = [report_notification, track_instance, untrack_instance]
 
-    def start(self):
-        endpoints = [report_notification, track_instance, untrack_instance]
-
-        transport = messaging.get_notification_transport(CONF)
-        s_target = target.Target(topic='murano', server=str(uuid.uuid4()))
-
-        self.server = messaging.get_notification_listener(
-            transport, [s_target], endpoints, executor='eventlet')
-
-        self.server.start()
-        super(NotificationService, self).start()
+    transport = messaging.get_transport(config.CONF)
+    s_target = target.Target(topic='murano', server=server_id)
+    dispatcher = oslo_dispatcher.NotificationDispatcher(
+        [s_target], endpoints, None, True)
+    return messaging.MessageHandlingServer(transport, dispatcher, 'eventlet')
 
 
-class ApiService(Service):
+def get_rpc_service():
+    global RPC_SERVICE
 
-    def start(self):
-        endpoints = [ResultEndpoint()]
+    if RPC_SERVICE is None:
+        RPC_SERVICE = _prepare_rpc_service(str(uuid.uuid4()))
+    return RPC_SERVICE
 
-        transport = messaging.get_rpc_transport(CONF)
-        s_target = target.Target('murano', 'results', server=str(uuid.uuid4()))
-        access_policy = dispatcher.DefaultRPCAccessPolicy
-        self.server = messaging.get_rpc_server(
-            transport, s_target, endpoints, 'eventlet',
-            access_policy=access_policy)
-        self.server.start()
-        super(ApiService, self).start()
+
+def get_notification_service():
+    global NOTIFICATION_SERVICE
+
+    if NOTIFICATION_SERVICE is None:
+        NOTIFICATION_SERVICE = _prepare_notification_service(str(uuid.uuid4()))
+    return NOTIFICATION_SERVICE
