@@ -18,7 +18,7 @@ import sqlalchemy as sa
 
 def transform_table(name, renames, defaults, *columns, **kw):
     def escape(val):
-        if isinstance(val, str):
+        if isinstance(val, (str, unicode)):
             return "'{0}'".format(val)
         elif val is None:
             return 'NULL'
