@@ -12,26 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
-from keystoneclient import exceptions as ks_exceptions
-from oslo_config import cfg
-from oslo_log import log as logging
-import six
-import yaml
-
-from murano.common import auth_utils
 from murano.common import uuidutils
 from murano.db import models
 from murano.db.services import sessions
 from murano.db import session as db_session
 from murano.services import states
 
-CONF = cfg.CONF
 
-LOG = logging.getLogger(__name__)
-DEFAULT_NETWORK_TYPES = {
-    "nova": 'io.murano.resources.NovaNetwork',
-    "neutron": 'io.murano.resources.NeutronNetwork'
+DEFAULT_NETWORKS = {
+    'environment': 'io.murano.resources.NeutronNetwork',
+    # 'flat': 'io.murano.resources.ExistingNetworkConnector'
 }
 
 
@@ -39,7 +29,6 @@ class EnvironmentServices(object):
     @staticmethod
     def get_environments_by(filters):
         """Returns list of environments
-
            :param filters: property filters
            :return: Returns list of environments
         """
@@ -67,7 +56,7 @@ class EnvironmentServices(object):
         :param environment_id: Id of environment for which we checking status.
         :return: Environment status
         """
-        # Deploying: there is at least one valid session with status deploying
+        #Deploying: there is at least one valid session with status `deploying`
         session_list = sessions.SessionServices.get_sessions(environment_id)
         has_opened = False
         for session in session_list:
@@ -81,42 +70,35 @@ class EnvironmentServices(object):
                 return states.EnvironmentStatus.DELETE_FAILURE
             elif session.state == states.SessionState.OPENED:
                 has_opened = True
-            elif session.state == states.SessionState.DEPLOYED:
-                break
         if has_opened:
             return states.EnvironmentStatus.PENDING
 
         return states.EnvironmentStatus.READY
 
     @staticmethod
-    def create(environment_params, context):
-        # tagging environment by tenant_id for later checks
+    def create(environment_params, tenant_id):
+        #tagging environment by tenant_id for later checks
         """Creates environment with specified params, in particular - name
 
            :param environment_params: Dict, e.g. {'name': 'env-name'}
-           :param context: request context to get the tenant id and the token
+           :param tenant_id: Tenant Id
            :return: Created Environment
         """
+
         objects = {'?': {
             'id': uuidutils.generate_uuid(),
         }}
-        network_driver = EnvironmentServices.get_network_driver(context)
         objects.update(environment_params)
-        if not objects.get('defaultNetworks'):
-            objects['defaultNetworks'] = \
-                EnvironmentServices.generate_default_networks(objects['name'],
-                                                              network_driver)
+        objects.update(
+            EnvironmentServices.generate_default_networks(objects['name']))
         objects['?']['type'] = 'io.murano.Environment'
-        objects['?']['metadata'] = {}
+        environment_params['tenant_id'] = tenant_id
 
         data = {
             'Objects': objects,
-            'Attributes': [],
-            'project_id': context.tenant,
-            'user_id': context.user
+            'Attributes': []
         }
 
-        environment_params['tenant_id'] = context.tenant
         environment = models.Environment()
         environment.update(environment_params)
 
@@ -124,7 +106,7 @@ class EnvironmentServices(object):
         with unit.begin():
             unit.add(environment)
 
-        # saving environment as Json to itself
+        #saving environment as Json to itself
         environment.update({'description': data})
         environment.save(unit)
 
@@ -135,7 +117,7 @@ class EnvironmentServices(object):
         """Deletes environment and notify orchestration engine about deletion
 
            :param environment_id: Environment that is going to be deleted
-           :param session_id: Session Id
+           :param token: OpenStack auth token
         """
 
         env_description = EnvironmentServices.get_environment_description(
@@ -211,33 +193,27 @@ class EnvironmentServices(object):
         session.save(unit)
 
     @staticmethod
-    def generate_default_networks(env_name, network_driver):
-        net_config = CONF.find_file(
-            CONF.networking.network_config_file)
-        if net_config:
-            LOG.debug("Loading network configuration from file")
-            with open(net_config) as f:
-                data = yaml.safe_load(f)
-                return EnvironmentServices._objectify(data, {
-                    'ENV': env_name
-                })
-
-        network_type = DEFAULT_NETWORK_TYPES[network_driver]
-        LOG.debug("Setting '{net_type}' as environment's "
-                  "default network".format(net_type=network_type))
+    def generate_default_networks(env_name):
+        # TODO(ativelkov):
+        # This is a temporary workaround. Need to find a better way:
+        # These objects have to be created in runtime when the environment is
+        # deployed for the first time. Currently there is no way to persist
+        # such changes, so we have to create the objects on the API side
         return {
-            'environment': {
-                '?': {
-                    'id': uuidutils.generate_uuid(),
-                    'type': network_type
+            'defaultNetworks': {
+                'environment': {
+                    '?': {
+                        'id': uuidutils.generate_uuid(),
+                        'type': DEFAULT_NETWORKS['environment']
+                    },
+                    'name': env_name + '-network'
                 },
-                'name': env_name + '-network'
-            },
-            'flat': None
+                'flat': None
+            }
         }
 
     @staticmethod
-    def deploy(session, unit, context):
+    def deploy(session, unit, token):
         environment = unit.query(models.Environment).get(
             session.environment_id)
 
@@ -245,41 +221,4 @@ class EnvironmentServices(object):
                 'ObjectsCopy' not in session.description):
             EnvironmentServices.remove(session.environment_id)
         else:
-            sessions.SessionServices.deploy(
-                session, environment, unit, context)
-
-    @staticmethod
-    def _objectify(data, replacements):
-        if isinstance(data, dict):
-            if isinstance(data.get('?'), dict):
-                data['?']['id'] = uuidutils.generate_uuid()
-            result = {}
-            for key, value in data.items():
-                result[key] = EnvironmentServices._objectify(
-                    value, replacements)
-            return result
-        elif isinstance(data, list):
-            return [EnvironmentServices._objectify(v, replacements)
-                    for v in data]
-        elif isinstance(data, six.string_types):
-            for key, value in replacements.items():
-                data = data.replace('%' + key + '%', value)
-        return data
-
-    @staticmethod
-    def get_network_driver(context):
-        driver = CONF.networking.driver
-        if driver:
-            LOG.debug("Will use {} as a network driver".format(driver))
-            return driver
-
-        session = auth_utils.get_token_client_session(
-            context.auth_token, context.tenant)
-        try:
-            session.get_endpoint(service_type='network')
-        except ks_exceptions.EndpointNotFound:
-            LOG.debug("Will use NovaNetwork as a network driver")
-            return "nova"
-        else:
-            LOG.debug("Will use Neutron as a network driver")
-            return "neutron"
+            sessions.SessionServices.deploy(session, environment, unit, token)
