@@ -10,7 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_serialization import jsonutils
+import anyjson
 import sqlalchemy as sa
 from sqlalchemy.dialects import mysql
 
@@ -23,9 +23,9 @@ class JsonBlob(sa.TypeDecorator):
     impl = sa.Text
 
     def process_bind_param(self, value, dialect):
-        return jsonutils.dumps(value)
+        return anyjson.serialize(value)
 
     def process_result_value(self, value, dialect):
         if value is not None:
-            return jsonutils.loads(value)
+            return anyjson.deserialize(value)
         return None
