@@ -40,57 +40,35 @@ class DslInvalidOperationError(Exception):
 
 class NoMethodFound(Exception):
     def __init__(self, name):
-        super(NoMethodFound, self).__init__('Method "%s" is not found' % name)
-
-
-class NoPropertyFound(Exception):
-    def __init__(self, name):
-        super(NoPropertyFound, self).__init__(
-            'Property "%s" is not found' % name)
+        super(NoMethodFound, self).__init__('Method %s is not found' % name)
 
 
 class NoClassFound(Exception):
-    def __init__(self, name, packages=None):
-        if packages is None:
-            packages = []
-        packages = ', '.join("{0}/{1}".format(p.name, p.version)
-                             for p in packages)
-        super(NoClassFound, self).__init__(
-            'Class "{0}" is not found in {1}'.format(name, packages))
+    def __init__(self, name):
+        super(NoClassFound, self).__init__('Class %s is not found' % name)
 
 
 class NoPackageFound(Exception):
     def __init__(self, name):
-        super(NoPackageFound, self).__init__(
-            'Package "%s" is not found' % name)
+        super(NoPackageFound, self).__init__('Package %s is not found' % name)
 
 
 class NoPackageForClassFound(Exception):
     def __init__(self, name):
-        super(NoPackageForClassFound, self).__init__('Package for class "%s" '
+        super(NoPackageForClassFound, self).__init__('Package for class %s '
                                                      'is not found' % name)
 
 
 class NoObjectFoundError(Exception):
     def __init__(self, object_id):
         super(NoObjectFoundError, self).__init__(
-            'Object "%s" is not found in object store' % object_id)
-
-
-class MethodNotExposed(Exception):
-    pass
+            'Object %s is not found in object store' % object_id)
 
 
 class AmbiguousMethodName(Exception):
     def __init__(self, name):
         super(AmbiguousMethodName, self).__init__(
-            'Found more than one method "%s"' % name)
-
-
-class AmbiguousClassName(Exception):
-    def __init__(self, name):
-        super(AmbiguousClassName, self).__init__(
-            'Found more than one version of class "%s"' % name)
+            'Found more that one method %s' % name)
 
 
 class DslContractSyntaxError(Exception):
@@ -98,17 +76,7 @@ class DslContractSyntaxError(Exception):
 
 
 class ContractViolationException(Exception):
-    def __init__(self, *args, **kwargs):
-        super(ContractViolationException, self).__init__(*args, **kwargs)
-        self._path = ''
-
-    @property
-    def path(self):
-        return self._path
-
-    @path.setter
-    def path(self, value):
-        self._path = value
+    pass
 
 
 class ValueIsMissingError(Exception):
@@ -126,32 +94,32 @@ class PropertyAccessError(Exception):
 class AmbiguousPropertyNameError(PropertyAccessError):
     def __init__(self, name):
         super(AmbiguousPropertyNameError, self).__init__(
-            'Found more than one property "%s"' % name)
+            'Found more that one property %s' % name)
 
 
 class NoWriteAccess(PropertyAccessError):
     def __init__(self, name):
         super(NoWriteAccess, self).__init__(
-            'Property "%s" is immutable to the caller' % name)
+            'Property %s is immutable to the caller' % name)
 
 
 class NoWriteAccessError(PropertyAccessError):
     def __init__(self, name):
         super(NoWriteAccessError, self).__init__(
-            'Property "%s" is immutable to the caller' % name)
+            'Property %s is immutable to the caller' % name)
 
 
 class PropertyReadError(PropertyAccessError):
     def __init__(self, name, murano_class):
         super(PropertyAccessError, self).__init__(
-            'Property "%s" in class "%s" cannot be read' %
+            'Property %s in class %s cannot be read' %
             (name, murano_class.name))
 
 
 class PropertyWriteError(PropertyAccessError):
     def __init__(self, name, murano_class):
         super(PropertyAccessError, self).__init__(
-            'Property "%s" in class "%s" cannot be written' %
+            'Property %s in class %s cannot be written' %
             (name, murano_class.name))
 
 
@@ -159,24 +127,4 @@ class UninitializedPropertyAccessError(PropertyAccessError):
     def __init__(self, name, murano_class):
         super(PropertyAccessError, self).__init__(
             'Access to uninitialized property '
-            '"%s" in class "%s" is forbidden' % (name, murano_class.name))
-
-
-class CircularExpressionDependenciesError(Exception):
-    pass
-
-
-class InvalidLhsTargetError(Exception):
-    def __init__(self, target):
-        super(InvalidLhsTargetError, self).__init__(
-            'Invalid assignment target "%s"' % target)
-
-
-class InvalidInheritanceError(Exception):
-    pass
-
-
-class ObjectDestroyedError(Exception):
-    def __init__(self, obj):
-        super(ObjectDestroyedError, self).__init__(
-            'Object {0} is already destroyed'.format(obj))
+            '%s in class %s is forbidden' % (name, murano_class.name))
