@@ -12,36 +12,41 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import types
 
-import six
+import eventlet.greenpool as greenpool
+import yaql.context
 
-from murano.dsl import constants
-from murano.dsl import dsl_exception
-from murano.dsl import exceptions
-from murano.dsl import expressions
-from murano.dsl import helpers
-from murano.dsl import yaql_expression
+import murano.dsl.dsl_exception as dsl_exception
+import murano.dsl.exceptions as exceptions
+import murano.dsl.expressions as expressions
+import murano.dsl.helpers as helpers
+import murano.dsl.yaql_expression as yaql_expression
 
 
 class CodeBlock(expressions.DslExpression):
     def __init__(self, body):
-        body = helpers.list_value(body)
-        self.code_block = list(map(expressions.parse_expression, body))
+        if not isinstance(body, types.ListType):
+            body = [body]
+        self.code_block = map(expressions.parse_expression, body)
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         for expr in self.code_block:
+            def action():
+                try:
+                    expr.execute(context, murano_class)
+                except (dsl_exception.MuranoPlException,
+                        exceptions.InternalFlowException):
+                    raise
+                except Exception as ex:
+                    raise dsl_exception.MuranoPlException.\
+                        from_python_exception(ex, context)
+
             if hasattr(expr, 'virtual_instruction'):
                 instruction = expr.virtual_instruction
-                context[constants.CTX_CURRENT_INSTRUCTION] = instruction
-
-            try:
-                expr.execute(context)
-            except (dsl_exception.MuranoPlException,
-                    exceptions.InternalFlowException):
-                raise
-            except Exception as ex:
-                raise dsl_exception.MuranoPlException.from_python_exception(
-                    ex, context)
+                helpers.execute_instruction(instruction, action, context)
+            else:
+                action()
 
 
 class MethodBlock(CodeBlock):
@@ -49,11 +54,11 @@ class MethodBlock(CodeBlock):
         super(MethodBlock, self).__init__(body)
         self._name = name
 
-    def execute(self, context):
-        new_context = context.create_child_context()
-        new_context[constants.CTX_VARIABLE_SCOPE] = True
+    def execute(self, context, murano_class):
+        new_context = yaql.context.Context(context)
+        new_context.set_data(self._name, '?currentMethod')
         try:
-            super(MethodBlock, self).execute(new_context)
+            super(MethodBlock, self).execute(new_context, murano_class)
         except exceptions.ReturnException as e:
             return e.value
         except exceptions.BreakException:
@@ -70,7 +75,7 @@ class ReturnMacro(expressions.DslExpression):
     def __init__(self, Return):
         self._value = Return
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         raise exceptions.ReturnException(
             helpers.evaluate(self._value, context))
 
@@ -80,7 +85,7 @@ class BreakMacro(expressions.DslExpression):
         if Break:
             raise exceptions.DslSyntaxError('Break cannot have value')
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         raise exceptions.BreakException()
 
 
@@ -89,36 +94,46 @@ class ContinueMacro(expressions.DslExpression):
         if Continue:
             raise exceptions.DslSyntaxError('Continue cannot have value')
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         raise exceptions.ContinueException()
 
 
 class ParallelMacro(CodeBlock):
     def __init__(self, Parallel, Limit=None):
         super(ParallelMacro, self).__init__(Parallel)
-        self._limit = Limit or len(self.code_block)
+        if Limit:
+            self._limit = yaql_expression.YaqlExpression(str(Limit))
+        else:
+            self._limit = len(self.code_block)
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         if not self.code_block:
             return
         limit = helpers.evaluate(self._limit, context)
-        helpers.parallel_select(
-            self.code_block,
-            lambda expr: expr.execute(context.create_child_context()),
-            limit)
+        gpool = greenpool.GreenPool(helpers.evaluate(limit, context))
+        for expr in self.code_block:
+            gpool.spawn_n(expr.execute, context, murano_class)
+        gpool.waitall()
 
 
 class IfMacro(expressions.DslExpression):
     def __init__(self, If, Then, Else=None):
+        if not isinstance(If, yaql_expression.YaqlExpression):
+            raise exceptions.DslSyntaxError(
+                'Condition must be of expression type')
         self._code1 = CodeBlock(Then)
         self._code2 = None if Else is None else CodeBlock(Else)
         self._condition = If
 
-    def execute(self, context):
-        if helpers.evaluate(self._condition, context):
-            self._code1.execute(context)
+    def execute(self, context, murano_class):
+        res = self._condition.evaluate(context)
+        if not isinstance(res, types.BooleanType):
+            raise exceptions.DslInvalidOperationError(
+                'Condition must be evaluated to boolean type')
+        if res:
+            self._code1.execute(context, murano_class)
         elif self._code2 is not None:
-            self._code2.execute(context)
+            self._code2.execute(context, murano_class)
 
 
 class WhileDoMacro(expressions.DslExpression):
@@ -128,10 +143,17 @@ class WhileDoMacro(expressions.DslExpression):
         self._code = CodeBlock(Do)
         self._condition = While
 
-    def execute(self, context):
-        while self._condition(context):
+    def execute(self, context, murano_class):
+        while True:
+            res = self._condition.evaluate(context)
+            if not isinstance(res, types.BooleanType):
+                raise exceptions.DslSyntaxError(
+                    'Condition must be of expression type')
             try:
-                self._code.execute(context)
+                if res:
+                    self._code.execute(context, murano_class)
+                else:
+                    break
             except exceptions.BreakException:
                 break
             except exceptions.ContinueException:
@@ -140,19 +162,19 @@ class WhileDoMacro(expressions.DslExpression):
 
 class ForMacro(expressions.DslExpression):
     def __init__(self, For, In, Do):
-        if not isinstance(For, six.string_types):
+        if not isinstance(For, types.StringTypes):
             raise exceptions.DslSyntaxError(
                 'For value must be of string type')
         self._code = CodeBlock(Do)
         self._var = For
         self._collection = In
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         collection = helpers.evaluate(self._collection, context)
         for t in collection:
-            context[self._var] = t
+            context.set_data(t, self._var)
             try:
-                self._code.execute(context)
+                self._code.execute(context, murano_class)
             except exceptions.BreakException:
                 break
             except exceptions.ContinueException:
@@ -167,11 +189,11 @@ class RepeatMacro(expressions.DslExpression):
         self._count = Repeat
         self._code = CodeBlock(Do)
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         count = helpers.evaluate(self._count, context)
-        for _ in range(0, count):
+        for t in range(0, count):
             try:
-                self._code.execute(context)
+                self._code.execute(context, murano_class)
             except exceptions.BreakException:
                 break
             except exceptions.ContinueException:
@@ -180,48 +202,58 @@ class RepeatMacro(expressions.DslExpression):
 
 class MatchMacro(expressions.DslExpression):
     def __init__(self, Match, Value, Default=None):
-        if not isinstance(Match, dict):
+        if not isinstance(Match, types.DictionaryType):
             raise exceptions.DslSyntaxError(
                 'Match value must be of dictionary type')
         self._switch = Match
         self._value = Value
         self._default = None if Default is None else CodeBlock(Default)
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         match_value = helpers.evaluate(self._value, context)
-        for key, value in self._switch.items():
+        for key, value in self._switch.iteritems():
             if key == match_value:
-                CodeBlock(value).execute(context)
+                CodeBlock(value).execute(context, murano_class)
                 return
         if self._default is not None:
-            self._default.execute(context)
+            self._default.execute(context, murano_class)
 
 
 class SwitchMacro(expressions.DslExpression):
     def __init__(self, Switch, Default=None):
-        if not isinstance(Switch, dict):
+        if not isinstance(Switch, types.DictionaryType):
             raise exceptions.DslSyntaxError(
                 'Switch value must be of dictionary type')
         self._switch = Switch
+        for key, value in self._switch.iteritems():
+            if not isinstance(key, (yaql_expression.YaqlExpression,
+                                    types.BooleanType)):
+                raise exceptions.DslSyntaxError(
+                    'Switch cases must be must be either '
+                    'boolean or expression')
         self._default = None if Default is None else CodeBlock(Default)
 
-    def execute(self, context):
+    def execute(self, context, murano_class):
         matched = False
-        for key, value in self._switch.items():
-            if helpers.evaluate(key, context):
+        for key, value in self._switch.iteritems():
+            res = helpers.evaluate(key, context)
+            if not isinstance(res, types.BooleanType):
+                raise exceptions.DslInvalidOperationError(
+                    'Switch case must be evaluated to boolean type')
+            if res:
                 matched = True
-                CodeBlock(value).execute(context)
+                CodeBlock(value).execute(context, murano_class)
 
         if self._default is not None and not matched:
-            self._default.execute(context)
+            self._default.execute(context, murano_class)
 
 
 class DoMacro(expressions.DslExpression):
     def __init__(self, Do):
         self._code = CodeBlock(Do)
 
-    def execute(self, context):
-        self._code.execute(context)
+    def execute(self, context, murano_class):
+        self._code.execute(context, murano_class)
 
 
 def register():
