@@ -15,40 +15,30 @@
 import os
 import shutil
 import sys
-
+import types
 import yaml
 
-from murano.common.helpers import path
+from murano.dsl import yaql_expression
+import murano.packages.application_package
 from murano.packages import exceptions
-from murano.packages import package_base
-
-RESOURCES_DIR_NAME = 'Resources/'
-HOT_FILES_DIR_NAME = 'HotFiles/'
-HOT_ENV_DIR_NAME = 'HotEnvironments/'
 
 
-class YAQL(object):
-    def __init__(self, expr):
-        self.expr = expr
+YAQL = yaql_expression.YaqlExpression
 
 
-class Dumper(yaml.SafeDumper):
+class Dumper(yaml.Dumper):
     pass
 
 
 def yaql_representer(dumper, data):
-    return dumper.represent_scalar(u'!yaql', data.expr)
-
+    return dumper.represent_scalar(u'!yaql', str(data))
 
 Dumper.add_representer(YAQL, yaql_representer)
 
 
-class HotPackage(package_base.PackageBase):
-    def __init__(self, format_name, runtime_version, source_directory,
-                 manifest):
-        super(HotPackage, self).__init__(
-            format_name, runtime_version, source_directory, manifest)
-
+class HotPackage(murano.packages.application_package.ApplicationPackage):
+    def __init__(self, source_directory, manifest, loader):
+        super(HotPackage, self).__init__(source_directory, manifest, loader)
         self._translated_class = None
         self._source_directory = source_directory
         self._translated_ui = None
@@ -57,33 +47,39 @@ class HotPackage(package_base.PackageBase):
     def classes(self):
         return self.full_name,
 
-    @property
-    def requirements(self):
-        return {}
-
     @property
     def ui(self):
         if not self._translated_ui:
             self._translated_ui = self._translate_ui()
         return self._translated_ui
 
+    @property
+    def raw_ui(self):
+        ui_obj = self.ui
+        result = yaml.dump(ui_obj, Dumper=Dumper, default_style='"')
+        return result
+
     def get_class(self, name):
         if name != self.full_name:
             raise exceptions.PackageClassLoadError(
                 name, 'Class not defined in this package')
         if not self._translated_class:
             self._translate_class()
-        return self._translated_class, '<generated code>'
+        return self._translated_class
+
+    def validate(self):
+        self.get_class(self.full_name)
+        if not self._translated_ui:
+            self._translated_ui = self._translate_ui()
+        super(HotPackage, self).validate()
 
     def _translate_class(self):
-        template_file = path.secure_join(
-            self._source_directory, 'template.yaml')
+        template_file = os.path.join(self._source_directory, 'template.yaml')
+        shutil.copy(template_file, self.get_resource(self.full_name))
 
         if not os.path.isfile(template_file):
             raise exceptions.PackageClassLoadError(
                 self.full_name, 'File with class definition not found')
-
-        shutil.copy(template_file, self.get_resource(self.full_name))
         with open(template_file) as stream:
             hot = yaml.safe_load(stream)
             if 'resources' not in hot:
@@ -93,76 +89,38 @@ class HotPackage(package_base.PackageBase):
             'Extends': 'io.murano.Application'
         }
 
-        hot_envs_path = path.secure_join(
-            self._source_directory, RESOURCES_DIR_NAME, HOT_ENV_DIR_NAME)
-
-        # if using hot environments, doing parameter validation with contracts
-        # will overwrite the parameters in the hot environment.
-        # don't validate parameters if hot environments exist.
-        validate_hot_parameters = (not os.path.isdir(hot_envs_path) or
-                                   not os.listdir(hot_envs_path))
-
-        parameters = HotPackage._build_properties(hot, validate_hot_parameters)
+        parameters = HotPackage._translate_parameters(hot)
         parameters.update(HotPackage._translate_outputs(hot))
         translated['Properties'] = parameters
 
-        files = HotPackage._translate_files(self._source_directory)
-        translated.update(HotPackage._generate_workflow(hot, files))
-
-        # use default_style with double quote mark because by default PyYAML
-        # doesn't put any quote marks ans as a result strings with e.g. dashes
-        # may be interpreted as YAQL expressions upon load
-        self._translated_class = yaml.dump(
-            translated, Dumper=Dumper, default_style='"')
+        translated.update(HotPackage._generate_workflow(hot))
+        self._translated_class = translated
 
     @staticmethod
-    def _build_properties(hot, validate_hot_parameters):
+    def _translate_parameters(hot):
         result = {
             'generatedHeatStackName': {
                 'Contract': YAQL('$.string()'),
                 'Usage': 'Out'
-            },
-            'hotEnvironment': {
-                'Contract': YAQL('$.string()'),
-                'Usage': 'In'
-            },
-            'name': {
-                'Contract': YAQL('$.string().notNull()'),
-                'Usage': 'In',
-
             }
         }
-
-        if validate_hot_parameters:
-            params_dict = {}
-            for key, value in (hot.get('parameters') or {}).items():
-                param_contract = HotPackage._translate_param_to_contract(value)
-                params_dict[key] = param_contract
-            result['templateParameters'] = {
-                'Contract': params_dict,
-                'Default': {},
-                'Usage': 'In'
-            }
-        else:
-            result['templateParameters'] = {
-                'Contract': {},
-                'Default': {},
-                'Usage': 'In'
-            }
-
+        for key, value in (hot.get('parameters') or {}).items():
+            result[key] = HotPackage._translate_parameter(value)
+        result['name'] = {'Usage': 'In',
+                          'Contract': YAQL('$.string().notNull()')}
         return result
 
     @staticmethod
-    def _translate_param_to_contract(value):
+    def _translate_parameter(value):
         contract = '$'
 
         parameter_type = value['type']
-        if parameter_type in ('string', 'comma_delimited_list', 'json'):
+        if parameter_type == 'string':
             contract += '.string()'
         elif parameter_type == 'number':
             contract += '.int()'
-        elif parameter_type == 'boolean':
-            contract += '.bool()'
+        elif parameter_type == 'json':
+            contract += '.object()'
         else:
             raise ValueError('Unsupported parameter type ' + parameter_type)
 
@@ -172,38 +130,22 @@ class HotPackage(package_base.PackageBase):
             if translated:
                 contract += translated
 
-        result = YAQL(contract)
+        result = {
+            'Contract': YAQL(contract),
+            "Usage": "In"
+        }
+        if 'default' in value:
+            result['Default'] = value['default']
         return result
 
     @staticmethod
     def _translate_outputs(hot):
-        contract = {}
-        for key in (hot.get('outputs') or {}).keys():
-            contract[key] = YAQL("$.string()")
-        return {
-            'templateOutputs': {
-                'Contract': contract,
-                'Default': {},
-                'Usage': 'Out'
+        result = {}
+        for key, value in (hot.get('outputs') or {}).items():
+            result[key] = {
+                "Contract": YAQL("$.string()"),
+                "Usage": "Out"
             }
-        }
-
-    @staticmethod
-    def _translate_files(source_directory):
-        hot_files_path = path.secure_join(
-            source_directory, RESOURCES_DIR_NAME, HOT_FILES_DIR_NAME)
-
-        return HotPackage._build_hot_resources(hot_files_path)
-
-    @staticmethod
-    def _build_hot_resources(basedir):
-        result = []
-        if os.path.isdir(basedir):
-            for root, _, files in os.walk(os.path.abspath(basedir)):
-                for f in files:
-                    full_path = path.secure_join(root, f)
-                    relative_path = os.path.relpath(full_path, basedir)
-                    result.append(relative_path)
         return result
 
     @staticmethod
@@ -252,19 +194,15 @@ class HotPackage(package_base.PackageBase):
 
     @staticmethod
     def _format_value(value):
-        if isinstance(value, str):
+        if isinstance(value, types.StringTypes):
             return str("'" + value + "'")
         return str(value)
 
     @staticmethod
-    def _generate_workflow(hot, files):
-        hot_files_map = {}
-        for f in files:
-            file_path = "$resources.string('{0}{1}')".format(
-                HOT_FILES_DIR_NAME, f)
-            hot_files_map[f] = YAQL(file_path)
-
-        hot_env = YAQL("$.hotEnvironment")
+    def _generate_workflow(hot):
+        template_parameters = {}
+        for key, value in (hot.get('parameters') or {}).items():
+            template_parameters[key] = YAQL("$." + key)
 
         deploy = [
             {YAQL('$environment'): YAQL(
@@ -276,72 +214,46 @@ class HotPackage(package_base.PackageBase):
             {
                 'If': YAQL('$.getAttr(generatedHeatStackName) = null'),
                 'Then': [
-                    YAQL("$.setAttr(generatedHeatStackName, "
-                         "'{0}_{1}'.format(randomName(), id($environment)))")
+                    YAQL('$.setAttr(generatedHeatStackName, randomName())')
                 ]
             },
             {YAQL('$stack'): YAQL(
-                "new('io.murano.system.HeatStack', $environment, "
+                "new('io.murano.system.HeatStack', "
                 "name => $.getAttr(generatedHeatStackName))")},
 
+
             YAQL("$reporter.report($this, "
                  "'Application deployment has started')"),
 
             {YAQL('$resources'): YAQL("new('io.murano.system.Resources')")},
-
             {YAQL('$template'): YAQL("$resources.yaml(type($this))")},
+            {YAQL('$parameters'): template_parameters},
             YAQL('$stack.setTemplate($template)'),
-            {YAQL('$parameters'): YAQL("$.templateParameters")},
             YAQL('$stack.setParameters($parameters)'),
-            {YAQL('$files'): hot_files_map},
-            YAQL('$stack.setFiles($files)'),
-            {YAQL('$hotEnv'): hot_env},
-            {
-                'If': YAQL("bool($hotEnv)"),
-                'Then': [
-                    {YAQL('$envRelPath'): YAQL("'{0}' + $hotEnv".format(
-                        HOT_ENV_DIR_NAME))},
-                    {YAQL('$hotEnvContent'): YAQL("$resources.string("
-                                                  "$envRelPath)")},
-                    YAQL('$stack.setHotEnvironment($hotEnvContent)')
-                ]
-            },
 
-            YAQL("$reporter.report($this, 'Stack creation has started')"),
-            {
-                'Try': [YAQL('$stack.push()')],
-                'Catch': [
-                    {
-                        'As': 'e',
-                        'Do': [
-                            YAQL("$reporter.report_error($this, $e.message)"),
-                            {'Rethrow': None}
-                        ]
-                    }
-                ],
-                'Else': [
-                    {YAQL('$.templateOutputs'): YAQL('$stack.output()')},
-                    YAQL("$reporter.report($this, "
-                         "'Stack was successfully created')"),
+            YAQL("$reporter.report($this, "
+                 "'Stack creation has started')"),
+            YAQL('$stack.push()'),
+            {YAQL('$outputs'): YAQL('$stack.output()')},
+            YAQL("$reporter.report($this, "
+                 "'Stack was successfully created')"),
 
-                    YAQL("$reporter.report($this, "
-                         "'Application deployment has finished')"),
-                ]
-            }
+            YAQL("$reporter.report($this, "
+                 "'Application deployment has finished')"),
         ]
+        for key, value in (hot.get('outputs') or {}).items():
+            deploy.append({YAQL('$.' + key): YAQL(
+                '$outputs.' + key)})
 
         destroy = [
-            {YAQL('$environment'): YAQL(
-                "$.find('io.murano.Environment').require()"
-            )},
             {YAQL('$stack'): YAQL(
-                "new('io.murano.system.HeatStack', $environment, "
+                "new('io.murano.system.HeatStack', "
                 "name => $.getAttr(generatedHeatStackName))")},
             YAQL('$stack.delete()')
         ]
 
         return {
-            'Methods': {
+            'Workflow': {
                 'deploy': {
                     'Body': deploy
                 },
@@ -353,10 +265,7 @@ class HotPackage(package_base.PackageBase):
 
     @staticmethod
     def _translate_ui_parameters(hot, title):
-        groups = hot.get('parameter_groups', [])
-        result_groups = []
-
-        predefined_fields = [
+        result = [
             {
                 'name': 'title',
                 'type': 'string',
@@ -370,36 +279,13 @@ class HotPackage(package_base.PackageBase):
                 'label': 'Application Name',
                 'required': True,
                 'description':
-                    'Enter a desired name for the application.'
-                    ' Just A-Z, a-z, 0-9, and dash are allowed'
+                        'Enter a desired name for the application.'
+                        ' Just A-Z, a-z, 0-9, and dash are allowed'
             }
         ]
-        used_parameters = set()
-        hot_parameters = hot.get('parameters') or {}
-        for group in groups:
-            fields = []
-            properties = []
-            for parameter in group.get('parameters', []):
-                parameter_value = hot_parameters.get(parameter)
-                if parameter_value:
-                    fields.append(HotPackage._translate_ui_parameter(
-                        parameter, parameter_value))
-                    used_parameters.add(parameter)
-                    properties.append(parameter)
-            result_groups.append((fields, properties))
-
-        rest_group = []
-        properties = []
-        for key, value in hot_parameters.items():
-            if key not in used_parameters:
-                rest_group.append(HotPackage._translate_ui_parameter(
-                    key, value))
-                properties.append(key)
-        if rest_group:
-            result_groups.append((rest_group, properties))
-
-        result_groups.insert(0, (predefined_fields, ['name']))
-        return result_groups
+        for key, value in (hot.get('parameters') or {}).items():
+            result.append(HotPackage._translate_ui_parameter(key, value))
+        return result
 
     @staticmethod
     def _translate_ui_parameter(name, parameter_spec):
@@ -408,19 +294,10 @@ class HotPackage(package_base.PackageBase):
             'label': name.title().replace('_', ' ')
         }
         parameter_type = parameter_spec['type']
-        if parameter_type == 'number':
-            translated['type'] = 'integer'
-        elif parameter_type == 'boolean':
-            translated['type'] = 'boolean'
-        else:
-            # string, json, and comma_delimited_list parameters are all
-            # displayed as strings in UI. Any unsupported parameter would also
-            # be displayed as strings.
+        if parameter_type == 'string':
             translated['type'] = 'string'
-
-        label = parameter_spec.get('label')
-        if label:
-            translated['label'] = label
+        elif parameter_type == 'number':
+            translated['type'] = 'integer'
 
         if 'description' in parameter_spec:
             translated['description'] = parameter_spec['description']
@@ -439,11 +316,11 @@ class HotPackage(package_base.PackageBase):
                 spec = constraint['length']
                 if 'min' in spec:
                     translated['minLength'] = max(
-                        translated.get('minLength', -sys.maxsize - 1),
+                        translated.get('minLength', -sys.maxint - 1),
                         int(spec['min']))
                 if 'max' in spec:
                     translated['maxLength'] = min(
-                        translated.get('maxLength', sys.maxsize),
+                        translated.get('maxLength', sys.maxint),
                         int(spec['max']))
 
             elif 'range' in constraint:
@@ -492,32 +369,20 @@ class HotPackage(package_base.PackageBase):
         return translated
 
     @staticmethod
-    def _generate_application_ui(groups, type_name,
-                                 package_name=None, package_version=None):
+    def _generate_application_ui(hot, type_name):
         app = {
             '?': {
                 'type': type_name
             }
         }
-        if package_name:
-            app['?']['package'] = package_name
-        if package_version:
-            app['?']['classVersion'] = package_version
-        for i, record in enumerate(groups):
-            if i == 0:
-                section = app
-            else:
-                section = app.setdefault('templateParameters', {})
-            for property_name in record[1]:
-                section[property_name] = YAQL(
-                    '$.group{0}.{1}'.format(i, property_name))
-        app['name'] = YAQL('$.group0.name')
+        for key in (hot.get('parameters') or {}).keys():
+            app[key] = YAQL('$.appConfiguration.' + key)
+        app['name'] = YAQL('$.appConfiguration.name')
 
         return app
 
     def _translate_ui(self):
-        template_file = path.secure_join(
-            self._source_directory, 'template.yaml')
+        template_file = os.path.join(self._source_directory, 'template.yaml')
 
         if not os.path.isfile(template_file):
             raise exceptions.PackageClassLoadError(
@@ -525,17 +390,18 @@ class HotPackage(package_base.PackageBase):
         with open(template_file) as stream:
             hot = yaml.safe_load(stream)
 
-        groups = HotPackage._translate_ui_parameters(hot, self.description)
-        forms = []
-        for i, record in enumerate(groups):
-            forms.append({'group{0}'.format(i): {'fields': record[0]}})
-
         translated = {
             'Version': 2,
             'Application': HotPackage._generate_application_ui(
-                groups, self.full_name, self.full_name, str(self.version)),
-            'Forms': forms
+                hot, self.full_name),
+            'Forms': [
+                {
+                    'appConfiguration': {
+                        'fields': HotPackage._translate_ui_parameters(
+                            hot, self.description)
+                    }
+                }
+            ]
         }
 
-        # see comment above about default_style
-        return yaml.dump(translated, Dumper=Dumper, default_style='"')
+        return translated
