@@ -18,9 +18,9 @@ import time
 import uuid
 
 import requests
+
 from tempest import clients
-from tempest.common import credentials_factory as common_creds
-from tempest.common import dynamic_creds
+from tempest.common import isolated_creds
 from tempest import config
 from tempest import test
 from tempest_lib.common import rest_client
@@ -44,8 +44,9 @@ class MuranoClient(rest_client.RestClient):
         return resp, json.loads(body)
 
     def create_environment(self, name):
-        body = {'name': name}
-        resp, body = self.post('v1/environments', json.dumps(body))
+        post_body = '{"name": "%s"}' % name
+
+        resp, body = self.post('v1/environments', post_body)
 
         return resp, json.loads(body)
 
@@ -106,9 +107,10 @@ class MuranoClient(rest_client.RestClient):
     def deploy_session(self, environment_id, session_id):
         post_body = None
         url = 'v1/environments/{0}/sessions/{1}/deploy'
-        resp, _ = self.post(url.format(environment_id, session_id), post_body)
+        resp, body = self.post(url.format(environment_id, session_id),
+                               post_body)
 
-        return resp
+        return resp, json.loads(body)
 
     def create_service(self, environment_id, session_id, post_body):
         post_body = json.dumps(post_body)
@@ -140,10 +142,9 @@ class MuranoClient(rest_client.RestClient):
 
     def get_services_list(self, environment_id, session_id):
         headers = self.get_headers()
-        if session_id:
-            headers.update(
-                {'X-Configuration-Session': session_id}
-            )
+        headers.update(
+            {'X-Configuration-Session': session_id}
+        )
 
         resp, body = self.get(
             'v1/environments/{0}/services'.format(environment_id),
@@ -209,141 +210,34 @@ class MuranoClient(rest_client.RestClient):
         return self.delete('v1/catalog/packages/{0}'.format(id))
 
     def download_package(self, id):
-        headers = {
-            'X-Auth-Token': self.auth_provider.get_token(),
-            'content-type': 'application/octet-stream'
-        }
-        return self.get('v1/catalog/packages/{0}/download'.format(id),
-                        headers=headers)
+        return self.get('v1/catalog/packages/{0}/download'.format(id))
 
     def get_ui_definition(self, id):
-        headers = {
-            'X-Auth-Token': self.auth_provider.get_token(),
-            'content-type': 'text/plain'
-        }
-        return self.get('v1/catalog/packages/{0}/ui'.format(id),
-                        headers=headers)
+        return self.get('v1/catalog/packages/{0}/ui'.format(id))
 
     def get_logo(self, id):
-        headers = {
-            'X-Auth-Token': self.auth_provider.get_token(),
-            'content-type': 'application/octet-stream'
-        }
-        return self.get('v1/catalog/packages/{0}/logo'.format(id),
-                        headers=headers)
+        return self.get('v1/catalog/packages/{0}/logo'.format(id))
 
     def list_categories(self):
         resp, body = self.get('v1/catalog/packages/categories')
 
         return resp, json.loads(body)
 
-    def get_env_templates_list(self):
-        """Check the environment templates deployed by the user."""
-        resp, body = self.get('v1/templates')
-
-        return resp, json.loads(body)
-
-    def create_env_template(self, env_template_name):
-        """Check the creation of an environment template."""
-        body = {'name': env_template_name}
-        resp, body = self.post('v1/templates', json.dumps(body))
-
-        return resp, json.loads(body)
-
-    def create_env_template_with_apps(self, env_template_name):
-        """Check the creation of an environment template."""
-        body = {'name': env_template_name}
-        body['services'] = [self._get_demo_app()]
-        resp, body = self.post('v1/templates', json.dumps(body))
-        return resp, json.loads(body)
-
-    def create_app_in_env_template(self, env_template_name):
-        """Check the creation of an environment template."""
-        resp, body = self.post('v1/templates/{0}/services'.
-                               format(env_template_name),
-                               json.dumps(self._get_demo_app()))
-        return resp, json.loads(body)
-
-    def get_apps_in_env_template(self, env_template_name):
-        """Check getting information about applications
-        in an environment template.
-        """
-        resp, body = self.get('v1/templates/{0}/services'.
-                              format(env_template_name))
-        return resp, json.loads(body)
-
-    def get_app_in_env_template(self, env_template_name, app_name):
-        """Check getting information about an application
-        in an environment template.
-        """
-        resp, body = self.get('v1/templates/{0}/services/{1}'.
-                              format(env_template_name, app_name))
-        return resp, json.loads(body)
-
-    def delete_app_in_env_template(self, env_template_name):
-        """Delete an application in an environment template."""
-        resp, _ = self.delete('v1/templates/{0}/services/{1}'.
-                              format(env_template_name, 'ID'))
-        return resp
-
-    def delete_env_template(self, env_template_id):
-        """Check the deletion of an environment template."""
-        resp, _ = self.delete('v1/templates/{0}'.format(env_template_id))
-        return resp
-
-    def get_env_template(self, env_template_id):
-        """Check getting information of an environment template."""
-        resp, body = self.get('v1/templates/{0}'.format(env_template_id))
-
-        return resp, json.loads(body)
-
-    def create_env_from_template(self, env_template_id, env_name):
-        """Check creating an environment from a template."""
-        body = {'name': env_name}
-        resp, body = self.post('v1/templates/{0}/create-environment'.
-                               format(env_template_id),
-                               json.dumps(body))
-        return resp, json.loads(body)
-
-    def _get_demo_app(self):
-        return {
-            "instance": {
-                "assignFloatingIp": "true",
-                "keyname": "mykeyname",
-                "image": "cloud-fedora-v3",
-                "flavor": "m1.medium",
-                "?": {
-                    "type": "io.murano.resources.LinuxMuranoInstance",
-                    "id": "ef984a74-29a4-45c0-b1dc-2ab9f075732e"
-                }
-            },
-            "name": "orion",
-            "port": "8080",
-            "?": {
-                "type": "io.murano.apps.apache.Tomcat",
-                "id": "ID"
-            }
-        }
-
 
 class TestCase(test.BaseTestCase):
-
     @classmethod
     def setUpClass(cls):
         super(TestCase, cls).setUpClass()
 
         # If no credentials are provided, the Manager will use those
         # in CONF.identity and generate an auth_provider from them
-        cls.creds = common_creds.get_configured_credentials(
-            credential_type='identity_admin')
-        mgr = clients.Manager(cls.creds)
+        mgr = clients.Manager()
         cls.client = MuranoClient(mgr.auth_provider)
 
     def setUp(self):
         super(TestCase, self).setUp()
 
         self.environments = []
-        self.env_templates = []
 
     def tearDown(self):
         super(TestCase, self).tearDown()
@@ -354,24 +248,12 @@ class TestCase(test.BaseTestCase):
             except exceptions.NotFound:
                 pass
 
-        for env_template in self.env_templates:
-            try:
-                self.client.delete_env_template(env_template['id'])
-            except exceptions.NotFound:
-                pass
-
     def create_environment(self, name):
         environment = self.client.create_environment(name)[1]
         self.environments.append(environment)
 
         return environment
 
-    def create_env_template(self, name):
-        env_template = self.client.create_env_template(name)[1]
-        self.env_templates.append(env_template)
-
-        return env_template
-
     def create_demo_service(self, environment_id, session_id, client=None):
         if not client:
             client = self.client
@@ -405,15 +287,6 @@ class NegativeTestCase(TestCase):
 
         # If no credentials are provided, the Manager will use those
         # in CONF.identity and generate an auth_provider from them
-        admin_creds = common_creds.get_configured_credentials(
-            credential_type='identity_admin')
-
-        cls.dynamic_creds = dynamic_creds.DynamicCredentialProvider(
-            identity_version='v2', name=cls.__name__, admin_creds=admin_creds)
-        creds = cls.dynamic_creds.get_alt_creds()
+        creds = isolated_creds.IsolatedCreds(cls.__name__).get_alt_creds()
         mgr = clients.Manager(credentials=creds)
         cls.alt_client = MuranoClient(mgr.auth_provider)
-
-    @classmethod
-    def purge_creds(cls):
-        cls.dynamic_creds.clear_creds()
