@@ -11,34 +11,31 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""
-Tests for database migrations.
-For the opportunistic testing you need to set up a db named 'openstack_citest'
-with user 'openstack_citest' and password 'openstack_citest' on localhost.
-The test will then use that db and u/p combo to run the tests.
-For postgres on Ubuntu this can be done with the following commands:
-sudo -u postgres psql
-postgres=# create user openstack_citest with createdb login password
-      'openstack_citest';
-postgres=# create database openstack_citest with owner openstack_citest;
-"""
-
 import datetime
 import uuid
 
-from oslo_db import exception as db_exc
-from oslo_db.sqlalchemy import test_base
-from oslo_db.sqlalchemy import utils as db_utils
-import sqlalchemy
+from oslo.config import cfg
+from oslo.db.sqlalchemy import utils as db_utils
+from sqlalchemy import exc
 
 from murano.db.migration import migration
+from murano.db import models  # noqa
 from murano.tests.unit.db.migration import test_migrations_base as base
 
+CONF = cfg.CONF
 
-class MuranoMigrationsCheckers(object):
 
-    snake_walk = True
-    downgrade = True
+class TestMigrations(base.BaseWalkMigrationTestCase, base.CommonTestsMixIn):
+
+    USER = "openstack_citest"
+    PASSWD = "openstack_citest"
+    DATABASE = "openstack_citest"
+
+    def __init__(self, *args, **kwargs):
+        super(TestMigrations, self).__init__(*args, **kwargs)
+
+    def setUp(self):
+        super(TestMigrations, self).setUp()
 
     def assertColumnExists(self, engine, table, column):
         t = db_utils.get_table(engine, table)
@@ -61,11 +58,6 @@ class MuranoMigrationsCheckers(object):
         index_names = [idx.name for idx in t.indexes]
         self.assertIn(index, index_names)
 
-    def assertColumnType(self, engine, table, column, sqltype):
-        t = db_utils.get_table(engine, table)
-        col = getattr(t.c, column)
-        self.assertIsInstance(col.type, sqltype)
-
     def assertIndexMembers(self, engine, table, index, members):
         self.assertIndexExists(engine, table, index)
 
@@ -78,9 +70,6 @@ class MuranoMigrationsCheckers(object):
 
         self.assertEqual(sorted(members), sorted(index_columns))
 
-    def test_walk_versions(self):
-        self.walk_versions(self.engine, self.snake_walk, self.downgrade)
-
     def _check_001(self, engine, data):
         self.assertEqual('001', migration.version(engine))
         self.assertColumnExists(engine, 'category', 'id')
@@ -105,7 +94,7 @@ class MuranoMigrationsCheckers(object):
 
         package = {
             'id': str(uuid.uuid4()),
-            'archive': b"archive blob here",
+            'archive': "archive blob here",
             'fully_qualified_name': 'com.example.package',
             'type': 'class',
             'author': 'OpenStack',
@@ -113,70 +102,24 @@ class MuranoMigrationsCheckers(object):
             'enabled': True,
             'description': 'some text',
             'is_public': False,
-            'logo': b"logo blob here",
+            'tags': ['tag1', 'tag2'],
+            'logo': "logo blob here",
             'ui_definition': '{}',
             'owner_id': '123',
             'created': datetime.datetime.now(),
             'updated': datetime.datetime.now()
         }
-        ins_stmt = package_table.insert(values=package)
-        engine.execute(ins_stmt)
+        package_table.insert().execute(package)
 
         package['id'] = str(uuid.uuid4())
-        self.assertRaises(db_exc.DBDuplicateEntry,
-                          engine.execute, ins_stmt)
+        self.assertRaises(exc.IntegrityError,
+                          package_table.insert().execute, package)
 
     def _check_002(self, engine, data):
         self.assertEqual('002', migration.version(engine))
-        self.assertColumnsExists(engine,
-                                 'package',
-                                 ['supplier_logo', 'supplier'])
+        self.assertColumnExists(engine, 'package', 'supplier_logo')
 
     def _check_003(self, engine, data):
         self.assertEqual('003', migration.version(engine))
         self.assertColumnExists(engine, 'task', 'action')
         self.assertColumnExists(engine, 'status', 'task_id')
-
-    def _check_004(self, engine, data):
-        self.assertEqual('004', migration.version(engine))
-        self.assertColumnType(engine,
-                              'package',
-                              'description',
-                              sqlalchemy.Text)
-
-    def _check_005(self, engine, data):
-        self.assertEqual('005', migration.version(engine))
-        self.assertColumnExists(engine, 'environment-template', 'id')
-        self.assertColumnExists(engine, 'environment-template', 'tenant_id')
-        self.assertColumnExists(engine, 'environment-template', 'name')
-
-    def _check_006(self, engine, data):
-        self.assertEqual('006', migration.version(engine))
-        self.assertColumnExists(engine, 'task', 'result')
-
-    def _check_007(self, engine, data):
-        self.assertEqual('007', migration.version(engine))
-        self.assertColumnExists(engine, 'locks', 'id')
-        self.assertColumnExists(engine, 'locks', 'ts')
-
-    def _check_008(self, engine, data):
-        self.assertEqual('008', migration.version(engine))
-        self.assertIndexExists(engine,
-                               'class_definition',
-                               'ix_class_definition_name')
-
-        self.assertIndexExists(engine,
-                               'package',
-                               'ix_package_fqn_and_owner')
-
-
-class TestMigrationsMySQL(MuranoMigrationsCheckers,
-                          base.BaseWalkMigrationTestCase,
-                          test_base.MySQLOpportunisticTestCase):
-    pass
-
-
-class TestMigrationsPostgresql(MuranoMigrationsCheckers,
-                               base.BaseWalkMigrationTestCase,
-                               test_base.PostgreSQLOpportunisticTestCase):
-    pass
