@@ -15,6 +15,10 @@
 
 import mock
 
+import yaql.context
+
+from murano.common import exceptions as exc
+from murano.engine import environment
 from murano.engine.system import agent
 from murano.engine.system import agent_listener
 from murano.tests.unit.dsl.foundation import object_model as om
@@ -30,20 +34,22 @@ class TestAgentListener(test_case.DslTestCase):
         model = om.Object(
             'AgentListenerTests')
         self.runner = self.new_runner(model)
+        self.context = yaql.context.Context()
+        self.context.set_data(environment.Environment(), '?environment')
 
     def test_listener_enabled(self):
         self.override_config('disable_murano_agent', False, 'engine')
         al = self.runner.testAgentListener()
         self.assertTrue(al.enabled)
-        al.subscribe('msgid', 'event')
+        al.subscribe('msgid', 'event', self.context)
         self.assertEqual({'msgid': 'event'}, al._subscriptions)
 
     def test_listener_disabled(self):
         self.override_config('disable_murano_agent', True, 'engine')
         al = self.runner.testAgentListener()
         self.assertFalse(al.enabled)
-        self.assertRaises(agent_listener.AgentListenerException,
-                          al.subscribe, 'msgid', 'event')
+        self.assertRaises(exc.PolicyViolationException,
+                          al.subscribe, 'msgid', 'event', None)
 
 
 class TestAgent(test_case.DslTestCase):
@@ -69,14 +75,14 @@ class TestAgent(test_case.DslTestCase):
 
             with mock.patch(agent_cls + '._send') as s:
                 s.return_value = mock.MagicMock()
-                a.sendRaw({})
-                s.assert_called_with({}, False)
+                a.sendRaw({}, None)
+                s.assert_called_with({}, False, None)
 
     def test_agent_disabled(self):
         self.override_config('disable_murano_agent', True, 'engine')
         a = self.runner.testAgent()
         self.assertFalse(a.enabled)
-        self.assertRaises(agent.AgentException, a.call, {}, None)
-        self.assertRaises(agent.AgentException, a.send, {}, None)
-        self.assertRaises(agent.AgentException, a.callRaw, {})
-        self.assertRaises(agent.AgentException, a.sendRaw, {})
+        self.assertRaises(exc.PolicyViolationException, a.call, {}, None, None)
+        self.assertRaises(exc.PolicyViolationException, a.send, {}, None, None)
+        self.assertRaises(exc.PolicyViolationException, a.callRaw, {}, None)
+        self.assertRaises(exc.PolicyViolationException, a.sendRaw, {}, None)
