@@ -12,8 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from murano.dsl import dsl
+import types
+
 from murano.dsl import exceptions
+from murano.dsl import murano_object
 from murano.tests.unit.dsl.foundation import object_model as om
 from murano.tests.unit.dsl.foundation import test_case
 
@@ -24,7 +26,6 @@ class TestContracts(test_case.DslTestCase):
         self._runner = self.new_runner(
             om.Object(
                 'ContractExamples',
-                ordinaryProperty='PROPERTY',
                 sampleClass=om.Object(
                     'SampleClass1',
                     stringProperty='string1',
@@ -34,13 +35,13 @@ class TestContracts(test_case.DslTestCase):
 
     def test_string_contract(self):
         result = self._runner.testStringContract('qwerty')
-        self.assertIsInstance(result, str)
-        self.assertEqual('qwerty', result)
+        self.assertIsInstance(result, types.StringTypes)
+        self.assertEqual(result, 'qwerty')
 
     def test_string_from_number_contract(self):
         result = self._runner.testStringContract(123)
-        self.assertIsInstance(result, str)
-        self.assertEqual('123', result)
+        self.assertIsInstance(result, types.StringTypes)
+        self.assertEqual(result, '123')
 
     def test_string_null_contract(self):
         self.assertIsNone(self._runner.testStringContract(None))
@@ -48,12 +49,12 @@ class TestContracts(test_case.DslTestCase):
     def test_int_contract(self):
         result = self._runner.testIntContract(123)
         self.assertIsInstance(result, int)
-        self.assertEqual(123, result)
+        self.assertEqual(result, 123)
 
     def test_int_from_string_contract(self):
         result = self._runner.testIntContract('456')
         self.assertIsInstance(result, int)
-        self.assertEqual(456, result)
+        self.assertEqual(result, 456)
 
     def test_int_from_string_contract_failure(self):
         self.assertRaises(exceptions.ContractViolationException,
@@ -65,29 +66,29 @@ class TestContracts(test_case.DslTestCase):
     def test_bool_contract(self):
         result = self._runner.testBoolContract(True)
         self.assertIsInstance(result, bool)
-        self.assertTrue(result)
+        self.assertIs(result, True)
 
         result = self._runner.testBoolContract(False)
         self.assertIsInstance(result, bool)
-        self.assertFalse(result)
+        self.assertIs(result, False)
 
     def test_bool_from_int_contract(self):
         result = self._runner.testBoolContract(10)
         self.assertIsInstance(result, bool)
-        self.assertTrue(result)
+        self.assertIs(result, True)
 
         result = self._runner.testBoolContract(0)
         self.assertIsInstance(result, bool)
-        self.assertFalse(result)
+        self.assertIs(result, False)
 
     def test_bool_from_string_contract(self):
         result = self._runner.testBoolContract('something')
         self.assertIsInstance(result, bool)
-        self.assertTrue(result)
+        self.assertIs(result, True)
 
         result = self._runner.testBoolContract('')
         self.assertIsInstance(result, bool)
-        self.assertFalse(result)
+        self.assertIs(result, False)
 
     def test_bool_null_contract(self):
         self.assertIsNone(self._runner.testIntContract(None))
@@ -95,12 +96,12 @@ class TestContracts(test_case.DslTestCase):
     def test_class_contract(self):
         arg = om.Object('SampleClass2', class2Property='qwerty')
         result = self._runner.testClassContract(arg)
-        self.assertIsInstance(result, dsl.MuranoObjectInterface)
+        self.assertIsInstance(result, murano_object.MuranoObject)
 
     def test_class_contract_by_ref(self):
         arg = om.Object('SampleClass2', class2Property='qwerty')
         result = self._runner.testClassContract(arg)
-        self.assertNotEqual(arg.id, result.id)
+        self.assertEqual(result.object_id, arg.id)
 
     def test_class_contract_failure(self):
         self.assertRaises(
@@ -121,39 +122,8 @@ class TestContracts(test_case.DslTestCase):
     def test_class_from_id_contract(self):
         object_id = self._runner.root.get_property('sampleClass').object_id
         result = self._runner.testClassFromIdContract(object_id)
-        self.assertIsInstance(result, dsl.MuranoObjectInterface)
-        self.assertEqual(object_id, result.id)
-
-    def test_template_contract(self):
-        arg = om.Object('CreatedClass2', property1='qwerty', property2=123)
-        result = self._runner.testTemplateContract(arg)
-        self.assertIsInstance(result, dict)
-        self.assertCountEqual(['?', 'property1', 'property2'], result.keys())
-
-    def test_template_property_contract(self):
-        template = {
-            'foo': 123
-        }
-        self.new_runner(
-            om.Object('ContractExamples', templateProperty=template))
-
-    def test_template_contract_fail_on_type(self):
-        arg = om.Object('SampleClass2', class2Property='qwerty')
-        self.assertRaises(
-            exceptions.ContractViolationException,
-            self._runner.testTemplateContract, arg)
-
-    def test_template_contract_with_property_exclusion(self):
-        arg = om.Object('CreatedClass2', property1='qwerty',
-                        property2='INVALID')
-        result = self._runner.testTemplateContractExcludeProperty(arg)
-        self.assertIsInstance(result, dict)
-        self.assertCountEqual(['?', 'property1'], result.keys())
-
-    def test_template_contract_with_property_exclusion_from_mpl(self):
-        result = self._runner.testTemplateContractExcludePropertyFromMpl()
-        self.assertIsInstance(result, dict)
-        self.assertCountEqual(['?', 'property1'], result.keys())
+        self.assertIsInstance(result, murano_object.MuranoObject)
+        self.assertEqual(result.object_id, object_id)
 
     def test_check_contract(self):
         arg = om.Object('SampleClass2', class2Property='qwerty')
@@ -320,32 +290,3 @@ class TestContracts(test_case.DslTestCase):
     def test_default(self):
         self.assertEqual('value', self._runner.testDefault('value'))
         self.assertEqual('DEFAULT', self._runner.testDefault())
-
-    def test_default_expression(self):
-        self.assertEqual('PROPERTY', self._runner.testDefaultExpression())
-        self.assertEqual('value', self._runner.testDefaultExpression('value'))
-
-    def test_template_with_externally_owned_object(self):
-        node = om.Object('Node', 'OBJ_ID')
-        node_template = om.Object('Node', nodes=['OBJ_ID'])
-        model = om.Object(
-            'TemplatePropertyClass', owned=node, template=node_template)
-        runner = self.new_runner(model)
-        self.assertEqual(
-            ['OBJ_ID'], runner.testTemplateWithExternallyOwnedObject())
-
-
-class TestContractsTransform(test_case.DslTestCase):
-    def setUp(self):
-        super(TestContractsTransform, self).setUp()
-        self._runner = self.new_runner(om.Object('TestIteratorsTransform'))
-
-    def test_property(self):
-        self.assertEqual('3', self._runner.testProperties())
-
-    def test_argument(self):
-        self.assertEqual('3', self._runner.testArgs())
-        self.assertEqual('2', self._runner.testUntypedArgs())
-        self.assertEqual('6', self._runner.testNotTypedListArgs())
-        self.assertEqual('6', self._runner.testTypedList())
-        self.assertEqual(2, self._runner.testListDict())
